@@ -1,10 +1,10 @@
 package App::ParseNetstat;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-10-17'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 1;
-# ABSTRACT: Parse netstat output
+# ABSTRACT: Parse netstat output (CLI)
 
 __END__
 
@@ -14,11 +14,11 @@ __END__
 
 =head1 NAME
 
-App::ParseNetstat - Parse netstat output
+App::ParseNetstat - Parse netstat output (CLI)
 
 =head1 VERSION
 
-This document describes version 0.13 of App::ParseNetstat (from Perl distribution App-ParseNetstat), released on 2016-01-18.
+This document describes version 0.14 of App::ParseNetstat (from Perl distribution App-ParseNetstat), released on 2016-10-17.
 
 =head1 HOMEPAGE
 
@@ -36,6 +36,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Parse::Netstat>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
